<template>
  <div class="policy-page">
    <!-- Header -->
    <header class="policy-header bg-white shadow-sm py-3 sticky-top">
      <div class="container-fluid">
        <div class="d-flex align-items-center justify-content-between">
          <nuxt-link to="/" class="text-default fs-4">
            <i class="icon icon-regular-angle-right"></i>
          </nuxt-link>
          <h4 class="m-0 fw-bold">
            <i class="icon icon-regular-info-circle ms-2"></i>{{ t('about_page.title') }}
          </h4>
          <div style="width: 24px"></div>
        </div>
      </div>
    </header>

    <!-- Main Content -->
    <main class="container-fluid pt-4 pb-5 mb-5">
      <!-- Hero Section -->
      <section class="policy-hero rounded-4 p-4 mb-4">
        <h5 class="fw-bold text-default mb-3">{{ t('about_page.contact_title') }}</h5>
        <p class="mb-0">{{ t('about_page.contact_text') }}</p>
      </section>

      <!-- Contact Info -->
      <div class="contact-card bg-white p-4 mb-4 rounded-3 shadow-sm">
        <div class="d-flex align-items-start mb-3">
          <i class="icon icon-regular-headphones text-default mt-1 ms-3 fs-2"></i>
          <div>
            <h6 class="fw-bold mb-2">{{ t('about_page.support_title') }}</h6>
            <p class="mb-1">{{ t('about_page.phone_label') }}: <strong>09905755358</strong></p>
            <small class="text-muted">{{ t('about_page.support_hours') }}</small>
          </div>
        </div>
      </div>

      <!-- Important Notice -->
      <div class="notice-card bg-white p-4 rounded-3 shadow-sm">
        <div class="d-flex align-items-start">
          <i class="icon icon-regular-shield text-default mt-1 ms-3 fs-2"></i>
          <div>
            <h6 class="fw-bold mb-2">{{ t('about_page.notice_title') }}</h6>
            <p class="mb-0">
              {{ t('about_page.notice_text') }}
              <a href="https://cyberpolice.ir" target="_blank" class="text-default">cyberpolice.ir</a>
              {{ t('about_page.notice_text_end') }}
            </p>
          </div>
        </div>
      </div>

      <!-- Quick Links -->
      <div class="quick-links mt-4">
        <h6 class="fw-bold mb-3">{{ t('about_page.quick_links_title') }}</h6>
        <div class="row g-3">
          <div class="col-md-6" v-for="(link, index) in quickLinks" :key="index">
            <nuxt-link :to="link.path" class="quick-link-card bg-white p-3 rounded-3 shadow-sm d-block">
              <div class="d-flex align-items-center">
                <i :class="link.icon + ' text-default ms-2 fs-4'" />
                <span>{{ t(link.title) }}</span>
              </div>
            </nuxt-link>
          </div>
        </div>
      </div>
    </main>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n';
const { t, locale } = useI18n();

definePageMeta({
  layout: "web"
});

const quickLinks = ref([
  {
    title: "about_page.quick_links.wallet_rules",
    path: "/page/walletrules",
    icon: "icon icon-regular-credit-card"
  },
  {
    title: "about_page.quick_links.privacy",
    path: "/page/privacypolicy",
    icon: "icon icon-regular-shield"
  }
]);
</script>


<style scoped>
/* استفاده از استایل‌های یکپارچه با صفحات قبلی */
.policy-hero {
  background: rgba(255, 152, 0, 0.1);
  border: 1px solid rgba(255, 152, 0, 0.2);
}

.contact-card, .notice-card {
  transition: all 0.3s ease;
  border-left: 3px solid #ff9800;
}

.contact-card:hover, .notice-card:hover {
  transform: translateY(-3px);
  box-shadow: 0 8px 20px rgba(255, 152, 0, 0.1);
}

.quick-link-card {
  transition: all 0.3s ease;
  color: #333;
  text-decoration: none;
}

.quick-link-card:hover {
  background-color: rgba(255, 152, 0, 0.1) !important;
  transform: translateX(-5px);
}

/* استفاده از کلاس‌های Bootstrap برای کاهش CSS اختصاصی */
</style>